@@ -37,7 +37,7 @@ from tensorflow.python.util.tf_export import tf_export
 
 
 @tf_export(v1=["train.Supervisor"])
-class Supervisor(object):
+class Supervisor:
   """A training helper that checkpoints models and computes summaries.
 
   This class is deprecated. Please use
